## 每日涨跌停价格

接口：stk_limit

描述：获取全市场（包含A/B股和基金）每日涨跌停价格，包括涨停价格，跌停价格等，每个交易日8点40左右更新当日股票涨跌停价格。

限量：单次最多提取5800条记录，可循环调取，总量不限制

积分：用户积2000积分可调取，单位分钟有流控，积分越高流量越大，请自行提高积分，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| ts_code | str | Y | TS股票代码 |
| pre_close | float | N | 昨日收盘价 |
| up_limit | float | Y | 涨停价 |
| down_limit | float | Y | 跌停价 |

接口示例

```python
pro = ts.pro_api()

#获取单日全部股票数据涨跌停价格
df = pro.stk_limit(trade_date='20190625')

#获取单个股票数据
df = pro.stk_limit(ts_code='002149.SZ', start_date='20190115', end_date='20190615')
```

数据示例

```python
trade_date    ts_code  up_limit  down_limit
0      20190625  000001.SZ     15.06       12.32
```